/*
 * The Spar Library - modular math parser
 * Copyright (C) 2000,2001 Davide Angelocola <davide178@inwind.it>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA  02111-1307, USA.
 *
 */

#ifndef _sl_errno_h_
#define _sl_errno_h_

/*
 *  sl_error_t
 *
 *  Parser error codes. 
 */
typedef enum sl_error
{
/*
 *  Don't use a standard error message: just print a message
 */
  SL_ERROR_CUSTOM,

/*
 *  Parser errors
 */
  SL_ERROR_SYNTAX,
  SL_ERROR_UNBALAN,
  SL_ERROR_DIVZERO,
  SL_ERROR_UNKNOWN,
  SL_ERROR_MAXVARS,
  SL_ERROR_BADFUNC,
  SL_ERROR_NUMARGS,
  SL_ERROR_NOARG,
  SL_ERROR_NEGARG,
  SL_ERROR_NULLARG,
  SL_ERROR_DOMAIN,
  SL_ERROR_CONST,
  SL_ERROR_RANGE,
  SL_ERROR_IDENF,

/*
 *  Module errors 
 *  provide a standard error message
 *  
 */
  SL_ERROR_MODULE_INIT,
  SL_ERROR_MODULE_LOAD,
  SL_ERROR_MODULE_RUN,
  SL_ERROR_MODULE_UNLOAD,

/*
 *  No memory 
 *  Fatal error  
 */
  SL_ERROR_NO_MEM,
  SL_ERROR_FREE_TWICE,
/*
 *  Non-fatal errors
 */

  SL_ERROR_MESSAGE,
/*
 *  This is the error counter
 *  it also means that there aren't error
 */

  SL_ERROR_NO
} sl_error;


#endif /* _sl_errno_h_ */
