/*
 * The Spar Library - modular math parser
 * Copyright (C) 2000,2001 Davide Angelocola <davide178@inwind.it>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA  02111-1307, USA.
 *
 */

#ifndef _sl_math_h_
#define _sl_math_h_

#include <spar/sl_constant.h>
#include <spar/sl_math_library.h>

/*
 *  Internal use
 */
#define __SL_MAX(a,b)      ((a) > (b) ? (a) : (b))
#define __SL_MIN(a,b)      ((a) > (b) ? (b) : (a))

#define SL_MAX(a,b)   __SL_MAX(a,b)
#define SL_MIN(a,b)   __SL_MIN(a,b)

#define SL_IS_ODD(x)     ((x) &1)
#define SL_IS_EVEN(x)    (!(SL_IS_ODD(x)))
#define SL_ABS(x)        (((x) < ZERO) ? (-(x)) : (x))
#define SL_SGN(x)        ((x) > ZERO? 1 : -1)
#define SL_IS_REAL(x) 	 (finite(x))

#define SL_IS_ZERO(x) 		(x == ZERO)
#define SL_IS_NOT_ZERO(x)	(x != ZERO)
#define SL_IS_NEGATIVE(x) 		(x < ZERO)
#define SL_IS_NOT_NEGATIVE(x) 		(!(SL_IS_NEGATIVE(x)))
#define SL_IS_POSITIVE(x)		(x > ZERO)
#define SL_IS_NOT_POSITIVE(x)		(!(SL_IS_NOT_POSITIVE(x)))

#define SL_TO_RAD(x) ((x * M_PI) / 180.0)
#define SL_TO_DEG(x) ((x * 180.0) / M_PI)

#define SL_DBL_SWAP(a,b) do { double tmp = b ; b = a ; a = tmp ; } while(0)

/*
 *  Some other structures (still not used)
 */
struct interval_s
{
  double begin;
  double end;
};

struct domain_s
{
  struct interval_s interval;
  double singularities[5];
};

typedef struct interval_s sl_interval;
typedef struct domain_s sl_domain;

#endif
